summaryrefslogtreecommitdiff
path: root/bean
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2013-05-07 13:47:22 +0200
committerStephan Bergmann <sbergman@redhat.com>2013-05-07 13:50:14 +0200
commit6c4a4eb84589c8a19d72c46169ba1a25159e4c1b (patch)
tree7fce0dff26b92a452a8ca086601699908dc6f67a /bean
parent98b1cd3598040c0e0048b97f4a780b5cae79cd6b (diff)
Revert to mis-typed com.sun.star.comp.beans.OOoBean.aquireSystemWindow again
...from 43debfae8326ad98f9d130aa450f59ad49577d55 "General cleanup of OfficeBeans," as this is a stable interface that should not be broken airily. Change-Id: I931a611341a1b29346d134c11ecf886fe7767836
Diffstat (limited to 'bean')
-rw-r--r--bean/com/sun/star/comp/beans/OOoBean.java4
-rw-r--r--bean/qa/complex/bean/OOoBeanTest.java8
-rw-r--r--bean/qa/complex/bean/WriterFrame.java4
3 files changed, 8 insertions, 8 deletions
diff --git a/bean/com/sun/star/comp/beans/OOoBean.java b/bean/com/sun/star/comp/beans/OOoBean.java
index 34d707816555..7562012a97d1 100644
--- a/bean/com/sun/star/comp/beans/OOoBean.java
+++ b/bean/com/sun/star/comp/beans/OOoBean.java
@@ -444,7 +444,7 @@ public class OOoBean
was made visible (java.lang.Component.setVisible(true)).
<p>
Another scenario is that a OOoBean contains a document and is removed
- from a Java container and later added again. Then acquireSystemWindow needs
+ from a Java container and later added again. Then aquireSystemWindow needs
to be called after the container window is displayed.
<p>
@@ -454,7 +454,7 @@ public class OOoBean
@throws NoConnectionException
if the connection is not established.
*/
- public synchronized void acquireSystemWindow()
+ public synchronized void aquireSystemWindow()
throws
SystemWindowException,
diff --git a/bean/qa/complex/bean/WriterFrame.java b/bean/qa/complex/bean/WriterFrame.java
index 31626468cc02..525ddf78fc48 100644
--- a/bean/qa/complex/bean/WriterFrame.java
+++ b/bean/qa/complex/bean/WriterFrame.java
@@ -61,7 +61,7 @@ class WriterFrame extends java.awt.Frame
pack();
setBounds(x, y, width, height);
setVisible(true);
- m_bean.acquireSystemWindow();
+ m_bean.aquireSystemWindow();
}
}
catch (Exception e)
@@ -193,7 +193,7 @@ class WriterFrame extends java.awt.Frame
public void addOOoBean() throws Exception
{
add(m_bean, BorderLayout.CENTER);
- m_bean.acquireSystemWindow();
+ m_bean.aquireSystemWindow();
validate();
}
diff --git a/bean/qa/complex/bean/OOoBeanTest.java b/bean/qa/complex/bean/OOoBeanTest.java
index bb12bca5aa05..fb0b5cc4b946 100644
--- a/bean/qa/complex/bean/OOoBeanTest.java
+++ b/bean/qa/complex/bean/OOoBeanTest.java
@@ -301,7 +301,7 @@ public class OOoBeanTest
}
}
/** Test repeated OOoBean.acquireSystemWindow and OOoBean.releaseSystemWindow
* calls.
* @throws Exception
*/
@@ -315,7 +315,7 @@ public class OOoBeanTest
for (int i = 0; i < 100; i++)
{
b.releaseSystemWindow();
- b.acquireSystemWindow();
+ b.aquireSystemWindow();
}
if (!f.checkUnoFramePosition())
{
@@ -418,7 +418,7 @@ public class OOoBeanTest
bean.releaseSystemWindow();
frame.remove(bean);
frame.add(bean, BorderLayout.CENTER);
- bean.acquireSystemWindow();
+ bean.aquireSystemWindow();
}
if (!isWindows())
@@ -503,7 +503,7 @@ public class OOoBeanTest
try {
frame.add(bean, BorderLayout.CENTER);
- bean.acquireSystemWindow();
+ bean.aquireSystemWindow();
frame.validate();
} catch (Exception e) {
e.printStackTrace();
@@ -301,7 +301,7 @@ public class OOoBeanTest
}
}
- /** Test repeated OOoBean.acquireSystemWindow and OOoBean.releaseSystemWindow
+ /** Test repeated OOoBean.aquireSystemWindow and OOoBean.releaseSystemWindow
* calls.
* @throws Exception